# -*- coding: utf-8 -*-

#Azureのアカウント情報は###で置きあえてある

import pyaudio  # 録音機能を使うためのライブラリ
import wave  # wavファイルを扱うためのライブラリ
import json
import requests
import os
from azure.storage.file import FileService
from azure.storage.file import ContentSettings

#recording(filename,record_seconds) ---ファイルの名前と録音する長さを入力すると、その名前のファイルを作成しその秒数だけ録音する
def recording(filename,record_seconds):
    RECORD_SECONDS =record_seconds # 録音する時間の長さ（秒）
    WAVE_OUTPUT_FILENAME = filename  # 音声を保存するファイル名

    # 基本情報の設定
    FORMAT = pyaudio.paInt16  # 音声のフォーマット

    CHANNELS = 1  # モノラル
    RATE = 16000  # サンプルレート
    CHUNK = 2**11  # データ点数
    audio = pyaudio.PyAudio()  # pyaudio.PyAudio()

    stream = audio.open(
        format=FORMAT,
        channels=CHANNELS,
        rate=RATE,
        input=True,
        frames_per_buffer=CHUNK)

    # --------------録音開始---------------
    frames = []
    for i in range(0, int(RATE / CHUNK * RECORD_SECONDS)):
        data = stream.read(CHUNK)
        frames.append(data)


    # --------------録音終了---------------

    stream.stop_stream()
    stream.close()
    audio.terminate()

    waveFile = wave.open(WAVE_OUTPUT_FILENAME, 'wb')
    waveFile.setnchannels(CHANNELS)
    waveFile.setsampwidth(audio.get_sample_size(FORMAT))
    waveFile.setframerate(RATE)
    waveFile.writeframes(b''.join(frames))
    waveFile.close()

#speech_to_text(wavefile) ---音声ファイルを渡すと、Azureに送って、返信のテキストを返す
def speech_to_text(wavefile):
    subscriptionKey ='###'
    base_url = 'https://eastasia.stt.speech.microsoft.com/speech/recognition/conversation/cognitiveservices/v1'
    params = '?language=ja-JP'
    constructed_url = base_url +  params
    headers = {
        'Ocp-Apim-Subscription-Key': subscriptionKey,
        'Content-type': 'audio/wav; codec=audio/pcm; samplerate=16000',
        'Accept':'application/json'
    }
    file=os.path.abspath(wavefile)
    wave=open(file,'rb')
    wavedata=wave.read()
    res=requests.post(constructed_url,data=wavedata,headers=headers)
    res_json = res.json()
    text=''
    if 'DisplayText' in res_json:
        text=res_json['DisplayText']
    return text

#clear_character(text.character): --テキストと文字を渡すとテキストから渡した文字を削除してテキストを返す
def clear_character(text,character):
    character=character.encode('utf-8')
    text=text.encode('utf-8')
    text=text.replace(character,b'')
    text=text.decode('utf-8')
    return text

#key_phrases(text): --テキストを渡すとキーフレーズのリストを返す
def key_phrases(text):
    subscription_key = '###'
    assert subscription_key

    text_analytics_base_url = "https://japaneast.api.cognitive.microsoft.com/text/analytics/v2.0"
    key_phrase_api_url = text_analytics_base_url + "/keyPhrases"
    documents = {'documents' : [
    {'id': '1', 'language': 'ja', 'text': text},
    ]}
    headers   = {'Ocp-Apim-Subscription-Key': subscription_key}
    response  = requests.post(key_phrase_api_url, headers=headers, json=documents)
    key_phrases_json = response.json()
    if key_phrases_json['documents']!=[]:
        return key_phrases_json['documents'][0]['keyPhrases']
    else:
        return []

#spellcheck(text): --テキストを渡すと、スペルをチェックして結果をjsonファイルで返す（ただし、現状は英語のみ）  

def replace_character(text,character1,character2):
    character1=character1.encode('utf-8')
    character2=character2.encode('utf-8')
    text=text.encode('utf-8')
    text=text.replace(character1,character2)
    text=text.decode('utf-8')
    return text

#最初と最後の重なり合う2つの文章をつなぎ合わせる
def connect_sentence(text1,text2):
    for i in range(len(text2)):
        key_text=text2[i:i+3]
        if len(key_text)<3:
            continue
        else:
            num=text1.rfind(key_text)
            if num!=-1:
                return text1[:num]+text2[i:]
    return text1+text2

#データをAzureのStorageに送信
def send_to_storage(filename,filetype):
    file_service = FileService(account_name='###', account_key='###')
    file_service.create_file_from_path(
    'tsuchiyashare',
    None, # We want to create this blob in the root directory, so we specify None for the directory_name
    filename,
    filename,
    content_settings=ContentSettings(content_type=filetype))



    